from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Int, File, Boolean, Float, String

Wtcns_V0_1_0 = CommandToolBuilder(tool="wtcns", base_command=["wtcns"], inputs=[ToolInput(tag="in_number_of_threads", input_type=Int(optional=True), prefix="-t", doc=InputDocumentation(doc="Number of threads, [16]")), ToolInput(tag="in_total_parallel_jobs", input_type=Int(optional=True), prefix="-P", doc=InputDocumentation(doc="Total parallel jobs, [1]")), ToolInput(tag="in_index_current_cpu", input_type=Int(optional=True), prefix="-p", doc=InputDocumentation(doc="Index of current job (0-based), [0]\nSuppose to run wtcns for the same layout file parallelly in 60 cpu. For cpu1, -P 60 -p 0; cpu2, -P 60 -p 1, ...")), ToolInput(tag="in_input_file_layout", input_type=File(optional=True), prefix="-i", doc=InputDocumentation(doc="Input file, layout from wtlay, +")), ToolInput(tag="in_output_file_sequences", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="Output file, consensus sequences, [STDOUT]")), ToolInput(tag="in_force_overwrite", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="Force overwrite")), ToolInput(tag="in_trun_homopolymer_compression", input_type=Boolean(optional=True), prefix="-H", doc=InputDocumentation(doc="Trun on homopolymer compression")), ToolInput(tag="in_zmer_window", input_type=Int(optional=True), prefix="-y", doc=InputDocumentation(doc="Zmer window, [800]")), ToolInput(tag="in_minimum_size_seeding", input_type=Int(optional=True), prefix="-R", doc=InputDocumentation(doc="Minimum size of seeding region within zmer window, [200]")), ToolInput(tag="in_maximum_variant_uncompressed", input_type=Int(optional=True), prefix="-l", doc=InputDocumentation(doc="Maximum variant of uncompressed sizes between two matched zmer, [2]")), ToolInput(tag="in_alignment_penalty_match", input_type=Int(optional=True), prefix="-M", doc=InputDocumentation(doc="Alignment penalty: match, [2]")), ToolInput(tag="in_alignment_penalty_mismatch", input_type=Int(optional=True), prefix="-X", doc=InputDocumentation(doc="Alignment penalty: mismatch, [-5]")), ToolInput(tag="in_alignment_penalty_insertion_deletion", input_type=Int(optional=True), prefix="-O", doc=InputDocumentation(doc="Alignment penalty: insertion or deletion, used in first round [-3]")), ToolInput(tag="in_alignment_penalty_insertion_used", input_type=Int(optional=True), prefix="-I", doc=InputDocumentation(doc="Alignment penalty: insertion, used in rounds after first, [-2]")), ToolInput(tag="in_alignment_penalty_deletion", input_type=Int(optional=True), prefix="-D", doc=InputDocumentation(doc="Alignment penalty: deletion, used in rounds after first, [-3]")), ToolInput(tag="in_alignment_penalty_gap", input_type=Int(optional=True), prefix="-E", doc=InputDocumentation(doc="Alignment penalty: gap extension, [-1]")), ToolInput(tag="in_alignment_penalty_read", input_type=Int(optional=True), prefix="-T", doc=InputDocumentation(doc="Alignment penalty: read end clipping [-10]")), ToolInput(tag="in_disable_phreadqv_refinealignment", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc="Disable PhreadQV in refine-alignment")), ToolInput(tag="in_minimum_bandwidth_iteratively", input_type=Int(optional=True), prefix="-w", doc=InputDocumentation(doc="Minimum bandwidth, iteratively doubled to maximum [50]")), ToolInput(tag="in_maximum_bandwidth", input_type=Int(optional=True), prefix="-W", doc=InputDocumentation(doc="Maximum bandwidth, [3200]")), ToolInput(tag="in_maximum_bandwidth_ending", input_type=Int(optional=True), prefix="-e", doc=InputDocumentation(doc="Maximum bandwidth at ending extension, [800]")), ToolInput(tag="in_basic_bandwidth_refinealignment", input_type=Int(optional=True), prefix="-r", doc=InputDocumentation(doc="Basic bandwidth in refine-alignment, [8]")), ToolInput(tag="in_minimum_alignment_identity", input_type=Float(optional=True), prefix="-m", doc=InputDocumentation(doc="Minimum alignment identity, [0.5]")), ToolInput(tag="in_penalty_backbone_edge", input_type=Float(optional=True), prefix="-Y", doc=InputDocumentation(doc="Penalty of backbone edge in calling consensus, [0.5]")), ToolInput(tag="in_penalty_alternative_edge", input_type=Float(optional=True), prefix="-N", doc=InputDocumentation(doc="Penalty of alternative edge in calling consensus, [0.2]\nThe above two options control whether the consensus look like backbone or alternative\nDefault 0.5 and 0.2, will let the consensus don't look like backbone")), ToolInput(tag="in_number_iterations_consensus", input_type=Int(optional=True), prefix="-n", doc=InputDocumentation(doc="Number of iterations for consensus calling, the larger, the accurater, the slower [6]")), ToolInput(tag="in_align_reads_final", input_type=String(optional=True), prefix="-a", doc=InputDocumentation(doc="Align reads against final consensus, and output to <-a>")), ToolInput(tag="in_disable_fast_zmer", input_type=Boolean(optional=True), prefix="-A", doc=InputDocumentation(doc="Disable fast zmer align in final aligning (see -a), use standard smith-waterman\nMore than once -A, will disable fast zmer align in all process")), ToolInput(tag="in_ouput_call_variants", input_type=Float(optional=True), prefix="-V", doc=InputDocumentation(doc="Ouput call variants and print to <-a>, -V 2.05 mean: min_allele_count>=2,min_allele_freq>=0.05")), ToolInput(tag="in_verbose_be_careful", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="Verbose, BE careful, HUGEEEEEEEE output on STDOUT"))], outputs=[ToolOutput(tag="out_output_file_sequences", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_file_sequences", type_hint=File()), doc=OutputDocumentation(doc="Output file, consensus sequences, [STDOUT]"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Wtcns_V0_1_0().translate("wdl", allow_empty_container=True)

